@@ -109,7 +109,7 @@ class Servico:
         executou_hoje = all([
             json.get('status') == 'S',
             fim_execucao,
-            datetime.strptime(fim_execucao, '%Y-%m-%dT%H:%M:%S.%f').date() == hoje.date(),
+            datetime.strptime(fim_execucao, '%Y-%m-%dT%H:%M:%S.%f').date() == hoje.date() if fim_execucao else False,
         ])
         return all([self.ativo(), not self.executado(), no_horario, not executou_hoje])
 
